#!/usr/bin/perl
# mktexmf.pl -- arrange and concatenate files according to TDS
# Copyright 2002 Christopher League <league@contrapunctus.net>
# This is free software under the GNU GPL; it comes with NO WARRANTY.

use strict;
use File::Basename;
use File::Path;
use NDBM_File;
use Fcntl;

chdir "work" || die "cd work: $!";

my $pkgdir = "../" . shift;
my $docdir = "../doc/gen";
my $toolsdir = "../tools";
my $supplier = "5";

## Find all the families in working directory
my @families;
foreach my $f (<*/*.tex>) {
    push @families, dirname $f;
}

## populate texmf tree
my $texmf = $pkgdir;
my $fonts = "$texmf/fonts";
my $tfm = "$fonts/tfm/fontsite";
my $vf = "$fonts/vf/fontsite";
my $latex = "$texmf/tex/latex/fontsite";
mkpath($latex);
foreach my $f (@families) {
    mkpath("$tfm/$f") and system("cp $f/*.tfm $tfm/$f");
    mkpath("$vf/$f") and system("cp $f/*.vf $vf/$f");
    system("cp $f/*.fd $f/*.sty $latex");
}
my $edition = `cat EDITION`;
$edition =~ s/\s//g;
foreach my $f (<$toolsdir/*.sty>) {
    system("sed 's/\@EDITION\@/$edition/g' $f >$latex/".(basename $f));
}

## dvips configuration
my $dvips = "$texmf/dvips";
my $dvienc = $dvips;    # "$dvips/fontsite";
mkpath($dvienc);
system("cp $toolsdir/*.enc $dvienc");

## concatenate map files
my $type1 = "$pkgdir/etc";;     # "$fonts/type1/fontsite";
my $dvimaps = "$dvips/config";
mkpath($type1);
mkpath($dvimaps);
system("cat */*.x11 | wc -l > $type1/fonts.scale");
system("cat */*.x11 >> $type1/fonts.scale");
system("cat */*.gs > $type1/Fontmap");
system("cat */*.map > $dvimaps/fs500tex.map");

## concatenate index files
mkpath($docdir);
foreach my $c (qw(expert extended garalde trans freeform slab symbol
                  blacklet uncial script decor modern osf sans sc)) {
    open(IDX, ">$docdir/$c.idx") or die "cannot write $docdir/$c.idx: $!";
    open(LST, ">$docdir/$c.lst") or die "cannot write $docdir/$c.lst: $!";
    print IDX "\@multitable \@columnfractions .4 .6\n";
    while (<*/$c.idx>) {
        open(IN, "$_") or die "cannot read $_: $!";
        while (<IN>) { print IDX $_; }
        close(IN);
    }
    while (<*/$c.lst>) {
        open(IN, "$_") or die "cannot read $_: $!";
        while (<IN>) { print LST $_; }
        close(IN);
    }
    print IDX "\@end multitable\n";
    close(IDX);
    close(LST);
}

# Concatenate faces in working directory into faces.tex
my $docfile = "$docdir/faces.tex";
open(DOC, ">$docfile") or die "cannot write $docfile: $!";
print DOC "\@menu\n";

my %names;
tie (%names, 'NDBM_File', 'names', O_RDWR|O_CREAT, 0644);

my %prevs;
my %nexts;
my $p = "Faces";
foreach my $f (@families) {
    $prevs{$f} = $p;
    $nexts{$p} = $f;
    $p = $f;
    print DOC "* $names{$f}::\n";
}
$nexts{$p} = "";
print DOC "\@end menu\n";

foreach my $f (@families) {
    print DOC "\@filbreak\n";
    print DOC "\@node $names{$f}, $names{$nexts{$f}}, $names{$prevs{$f}}, Faces\n";
    while (<$f/*.tex>) {
        open(IN, "$_") or die "cannot read $_: $!";
        while (<IN>) { print DOC $_; }
        close(IN);
    }
}

close(DOC);
untie %names;
exit 0;


